@@ -1,7 +1,7 @@
 # Main running methods file
 package Lemonldap::NG::Handler::Main::Run;
 
-our $VERSION = '2.0.12';
+our $VERSION = '2.0.14';
 
 package Lemonldap::NG::Handler::Main;
 
@@ -140,7 +140,7 @@ sub run {
 
     # Try to recover cookie and user session
     $id = $class->fetchId($req);
-    $class->data( {} ) unless($id);
+    $class->data( {} ) unless ($id);
     if (    $id
         and $session = $class->retrieveSession( $req, $id ) )
     {
@@ -321,7 +321,7 @@ sub getLevel {
         $i++
       )
     {
-        if ( $uri =~ $class->tsv->{locationRegexp}->{$vhost}->[$i] ) {
+        if ( $uri && $uri =~ $class->tsv->{locationRegexp}->{$vhost}->[$i] ) {
             $level = $class->tsv->{locationAuthnLevel}->{$vhost}->[$i];
             last;
         }
@@ -504,7 +504,7 @@ sub fetchId {
       if $class->_isHttps( $req, $vhost );
     my $lookForHttpCookie = ( $class->tsv->{securedCookie} =~ /^(2|3)$/
           and not $class->_isHttps( $req, $vhost ) );
-    my $cn = $class->tsv->{cookieName};
+    my $cn    = $class->tsv->{cookieName};
     my $value = $lookForHttpCookie    # Avoid prefix and bad cookie name (#2417)
       ? ( $t =~ /(?<![-.~])\b${cn}http=([^,; ]+)/o ? $1 : 0 )
       : ( $t =~ /(?<![-.~])\b$cn=([^,; ]+)/o       ? $1 : 0 );
@@ -536,8 +536,8 @@ sub retrieveSession {
     #     (15 seconds)
     if (    defined $class->data->{_session_id}
         and $id eq $class->data->{_session_id}
-        and
-        ( $now - $class->dataUpdate < $class->tsv->{handlerInternalCache} ) )
+        and ( $now - $class->dataUpdate < $class->tsv->{handlerInternalCache} )
+      )
     {
         $class->logger->debug("Get session $id from Handler internal cache");
         return $class->data;
@@ -734,10 +734,10 @@ sub sendHeaders {
           $class->tsv->{forgeHeaders}->{$vhost}->( $req, $session );
         foreach my $h ( sort keys %headers ) {
             if ( defined( my $v = $headers{$h} ) ) {
-                $class->logger->debug("Send header $h with value $v");
+                $class->logger->debug("Send header '$h' with value '$v'");
             }
             else {
-                $class->logger->debug("Send header $h with empty value");
+                $class->logger->debug("Send header '$h' with an empty value");
             }
         }
         $class->set_header_in( $req, %headers );
@@ -898,7 +898,9 @@ sub postJavascript {
     my $filler;
     foreach my $name ( keys %$data ) {
         use bytes;
-        my $value = "x" x bytes::length( $data->{$name} );
+        my @characterSet = ( '0' .. '9', 'A' .. 'Z', 'a' .. 'z' );
+        my $value        = join '' => map $characterSet[ rand @characterSet ],
+          1 .. bytes::length( $data->{$name} );
         $filler .=
 "form.find('input[name=\"$name\"], select[name=\"$name\"], textarea[name=\"$name\"]').val('$value')\n";
     }
