@@ -1,8 +1,8 @@
 package Lemonldap::NG::Handler::Main::SharedVariables;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.12';
 
-# Since handler has no instances but only static classes, this module provides
+# Since handler has no instance but only static classes, this module provides
 # classes properties with accessors
 
 package Lemonldap::NG::Handler::Main;
@@ -14,6 +14,7 @@ BEGIN {
     our $_tshv = {
         tsv         => {},
         cfgNum      => 0,
+        cfgDate     => 0,
         lastCheck   => 0,
         checkTime   => 600,
         confAcc     => {},
@@ -24,13 +25,13 @@ BEGIN {
     };
 
     # Current sessions properties
-    our $_v = { session => {}, datas => {}, datasUpdate => {}, };
+    our $_v = { data => {}, dataUpdate => {}, };
 
     # Thread shared accessors
     foreach ( keys %$_tshv ) {
         eval " sub $_ {
             my \$v = \$_[1];
-            \$_tshv->{$_} = \$v if(defined \$v);
+            \$_tshv->{$_} = \$v if (defined \$v);
             return \$_tshv->{$_};
         }";
         die $@ if ($@);
@@ -41,7 +42,7 @@ BEGIN {
     foreach ( keys %$_v ) {
         eval " sub $_ {
             my \$v = \$_[1];
-            \$_v->{$_} = \$v if(\$v);
+            \$_v->{$_} = \$v if (\$v);
             return \$_v->{$_};
         }";
         die $@ if ($@);
