@@ -4,6 +4,7 @@ use strict;
 use 5.10.0;
 use POSIX 'strftime';
 use Data::Dumper;
+use Time::Fake;
 use_ok('Lemonldap::NG::Common::PSGI::Cli::Lib');
 
 our $client;
@@ -30,6 +31,7 @@ sub init {
         cookieName          => 'lemonldap',
         securedCookie       => 0,
         https               => 0,
+        hiddenAttributes    => 'mail cn',
         logger              => 'Lemonldap::NG::Common::Logger::Std',
         %$prms
     );
@@ -40,23 +42,53 @@ sub init {
     );
     ok( $client->app, 'App object' ) or explain( $client, '->app...' );
     count(3);
-    open F, ">$file"
-      or die $!;
+
     my $now = time;
     my $ts  = strftime "%Y%m%d%H%M%S", localtime;
 
-    print F '{"_updateTime":"'
-      . $ts
-      . '","_timezone":"1","_session_kind":"SSO","_passwordDB":"Demo","_startTime":"'
-      . $ts
-      . '","ipAddr":"127.0.0.1","UA":"Mozilla/5.0 (X11; VAX4000; rv:43.0) Gecko/20100101 Firefox/143.0 Iceweasel/143.0.1","_user":"dwho","_userDB":"Demo","_lastAuthnUTime":'
-      . $now
-      . ',"uid":"dwho","_issuerDB":"Null","_session_id":"f5eec18ebb9bc96352595e2d8ce962e8ecf7af7c9a98cb9a43f9cd181cf4b545","authenticationLevel":1,"_whatToTrace":"dwho","_auth":"Demo","_utime":'
-      . $now
-      . ',"_loginHistory":{"successLogin":[{"ipAddr":"127.0.0.1","_utime":'
-      . $now
-      . '}]},"cn":"Doctor Who","mail":"dwho@badwolf.org"}';
-    close F;
+    my $sessionData = {
+        '_timezone'     => '1',
+        'groups'        => 'users; timelords',
+        'uid'           => 'dwho',
+        '_loginHistory' => {
+            'successLogin' => [ {
+                    '_utime' => $now,
+                    'ipAddr' => '127.0.0.1'
+                }
+            ]
+        },
+        'cn'              => 'Doctor Who',
+        '_lastAuthnUTime' => $now,
+        '_whatToTrace'    => 'dwho',
+        '_issuerDB'       => 'Null',
+        '_startTime'      => "$ts",
+        '_user'           => 'dwho',
+        '_updateTime'     => "$ts",
+        '_userDB'         => 'Demo',
+        'hGroups'         => {
+            'users'     => {},
+            'timelords' => {}
+        },
+        'ipAddr'              => '127.0.0.1',
+        'mail'                => 'dwho@badwolf.org',
+        'authenticationLevel' => 1,
+        '_utime'              => $now,
+        '_passwordDB'         => 'Demo',
+        '_auth'               => 'Demo',
+        'UA'                  =>
+'Mozilla/5.0 (X11; VAX4000; rv:43.0) Gecko/20100101 Firefox/143.0 Iceweasel/143.0.1'
+    };
+
+    my $as = Lemonldap::NG::Common::Session->new( {
+            storageModule        => 'Apache::Session::File',
+            storageModuleOptions => { Directory => 't/sessions' },
+            id                   => $sessionId,
+            force                => 1,
+            kind                 => 'SSO',
+            info                 => $sessionData,
+        }
+    );
+
 }
 
 sub client {
@@ -83,7 +115,8 @@ sub explain {
 }
 
 sub clean {
-    unlink $file;
+    unlink glob 't/sessions/*';
+    unlink glob 't/sessions/lock/*';
 }
 
 package Lemonldap::NG::Handler::PSGI::Cli::Lib;
@@ -119,7 +152,7 @@ sub _get {
             'X_ORIGINAL_URI'       => $path . ( $query ? "?$query" : '' ),
             'SERVER_PORT'          => '80',
             'SERVER_PROTOCOL'      => 'HTTP/1.1',
-            'HTTP_USER_AGENT' =>
+            'HTTP_USER_AGENT'      =>
               'Mozilla/5.0 (VAX-4000; rv:36.0) Gecko/20350101 Firefox',
             'REMOTE_ADDR' => '127.0.0.1',
             'HTTP_HOST'   => $host,
